;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "elfeed" "20241202.22"
  "An Emacs Atom/RSS feed reader."
  '((emacs "24.3"))
  :url "https://github.com/skeeto/elfeed"
  :commit "a39fb78e34ee25dc8baea83376f929d7c128344f"
  :revdesc "a39fb78e34ee"
  :authors '(("Christopher Wellons" . "wellons@nullprogram.com"))
  :maintainers '(("Christopher Wellons" . "wellons@nullprogram.com")))
